@@ -8,18 +8,21 @@ import pandas as pd
 from abc import ABC, abstractmethod
 import numpy as np
 
+nifty_next_50 = ["ABBOTINDIA", "ACC", "ADANIENT", "ADANIGREEN", "ADANITRANS", "ALKEM", "AMBUJACEM", "APOLLOHOSP", "AUROPHARMA", "DMART", "BAJAJHLDNG", "BANDHANBNK", "BERGEPAINT", "BIOCON", "BOSCHLTD", "CADILAHC", "COLPAL", "DABUR", "DLF", "GAIL", "GODREJCP", "HAVELLS", "HDFCAMC", "HINDPETRO", "ICICIGI", "ICICIPRULI", "IGL", "NAUKRI", "INDIGO", "JUBLFOOD", "LTI", "LUPIN", "MARICO", "MOTHERSUMI", "MRF", "MUTHOOTFIN", "NMDC", "PETRONET", "PIDILITIND", "PEL", "PGHH", "PNB", "SBICARD", "SIEMENS", "TORNTPHARM", "UBL", "MCDOWELL-N", "VEDL", "YESBANK"]
+
 class Strategy:
     
     file_path = '{0}_Strategy.json'.format(datetime.today().strftime("%Y%m%d"))
     saved_data = {}
     
-    def __init__( self, period = 700, target = .3, stop_loss = .15, tsl_period = 10, useSD = False, save = True):
+    def __init__( self, period = 700, target = .3, stop_loss = .15, tsl_period = 10, useSD = False, save = True, ticker_list = None):
         self.period = period
         self.target = target
         self.stop_loss = stop_loss
         self.tsl_period = tsl_period
         self.useSD = useSD
         self.save = save
+        self.ticker_list = ticker_list
         
         self.saved_data = self.loadFromFile()
     
@@ -40,8 +43,11 @@ class Strategy:
             return {}
         
     def getTickerList(self, pending = False, processed = False):
-        ticker_list = [ticker['Ticker'] for ticker in get_ticker_list()]
-
+        if self.ticker_list is None:
+            ticker_list = [ticker['Ticker'] for ticker in get_ticker_list()]
+            ticker_list = ticker_list + nifty_next_50
+        else:
+            ticker_list = self.ticker_list
         processed_tickers = self.saved_data.get('processed_tickers', [])
         pending_tickers = list(set(ticker_list) - set(processed_tickers))
         if pending:
